summaryrefslogtreecommitdiffstats
path: root/ksysv/kscroller.h
diff options
context:
space:
mode:
Diffstat (limited to 'ksysv/kscroller.h')
-rw-r--r--ksysv/kscroller.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/ksysv/kscroller.h b/ksysv/kscroller.h
index ae57487..9bcddab 100644
--- a/ksysv/kscroller.h
+++ b/ksysv/kscroller.h
@@ -13,18 +13,19 @@ class TQScrollBar;
* @author Peter Putzer <putzer@kde.org>
* @version $Id$
*/
-class KScroller : public QFrame
+class KScroller : public TQFrame
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor.
*
* @param parent the parent of this widget (passed on as ususal).
* @param name the name of this widget (as above).
*/
- KScroller (TQWidget* parent = 0L, const char* name = 0L);
+ KScroller (TQWidget* tqparent = 0L, const char* name = 0L);
/**
* Destructor.
@@ -69,7 +70,7 @@ public slots:
void setCornerWidget (TQWidget* corner);
/**
* Update the scrollbars. Call whenever you change the contents minimumSize.
*/
void updateScrollBars ();
@@ -82,12 +83,12 @@ protected:
/**
* Reimplemented for internal reasons, the API is not affected.
*/
- virtual TQSize sizeHint() const;
+ virtual TQSize tqsizeHint() const;
/**
* Reimplemented for internal reasons, the API is not affected.
*/
- virtual TQSize minimumSizeHint() const;
+ virtual TQSize tqminimumSizeHint() const;
private slots:
@@ -13,18 +13,19 @@ class TQScrollBar;
* Constructor.
*
- * @param parent the parent of this widget (passed on as ususal).
+ * @param tqparent the tqparent of this widget (passed on as ususal).
* @param name the name of this widget (as above).
*/
@@ -69,7 +70,7 @@ public slots:
void setCornerWidget (TQWidget* corner);
/**
- * Update the scrollbars. Call whenever you change the contents minimumSize.
+ * Update the scrollbars. Call whenever you change the contents tqminimumSize.
*/
void updateScrollBars ();